HasDaddr

Trait HasDaddr 

pub trait HasDaddr {
    // Required method
    fn daddr(&self) -> Daddr;
}
Memory objects that have a mapped address in the device address space.

Required Methods

fn daddr(&self) -> Daddr

Returns the base address of the mapping in the device address space.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: HasDaddr> HasDaddr for &T

Source

fn daddr(&self) -> usize

Source

impl<T: HasDaddr> HasDaddr for &mut T

Source

fn daddr(&self) -> usize

Source

impl<T: HasDaddr> HasDaddr for Arc<T>

Source

fn daddr(&self) -> usize

Source

impl<T: HasDaddr> HasDaddr for Box<T>

Source

fn daddr(&self) -> usize

Source

impl<T: HasDaddr> HasDaddr for Rc<T>

Source

fn daddr(&self) -> usize

Implementors